package info.msxlaunchers.openmsx.common;

import info.msxlaunchers.openmsx.common.NumericalEnum;
import info.msxlaunchers.openmsx.common.Utils;

import java.util.HashSet;
import java.util.Set;

import org.junit.Test;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class UtilsTest
{
	@Test
	public void testGetNumber()
	{
		assertEquals( Utils.getNumber( null ), 0 );
		assertEquals( Utils.getNumber( "" ), 0 );
		assertEquals( Utils.getNumber( " " ), 0 );
		assertEquals( Utils.getNumber( "100" ), 100 );
		assertEquals( Utils.getNumber( "-100" ), -100 );
		assertEquals( Utils.getNumber( "a100" ), 0 );
		assertEquals( Utils.getNumber( "100a" ), 0 );
	}

	@Test
	public void testGetStringForInt()
	{
		assertEquals( Utils.getString( 0 ), "0" );
		assertEquals( Utils.getString( -10 ), "-10" );
		assertEquals( Utils.getString( 10 ), "10" );
		assertEquals( Utils.getString( Integer.MAX_VALUE ), "2147483647" );
		assertEquals( Utils.getString( Integer.MIN_VALUE ), "-2147483648" );
	}

	@Test
	public void testGetStringForLong()
	{
		assertEquals( Utils.getString( 0L ), "0" );
		assertEquals( Utils.getString( -10L ), "-10" );
		assertEquals( Utils.getString( 10L ), "10" );
		assertEquals( Utils.getString( Long.MAX_VALUE ), "9223372036854775807" );
		assertEquals( Utils.getString( Long.MIN_VALUE ), "-9223372036854775808" );
	}

	@Test
	public void testGetEnumValue()
	{
		assertEquals( Utils.getEnumValue( null ), "0" );
		assertEquals( Utils.getEnumValue( NumericalEnumImpl.TEST ), "1" );
	}

	@Test
	public void testNotNullPass()
	{
		String string = "something";
		assertEquals( Utils.notNull( "string", string ), string );
	}

	@Test (expected = NullPointerException.class )
	public void testNotNullFail()
	{
		String nullString = null;
		Utils.notNull( "nullString", nullString );
	}

	@Test
	public void testIsEmpty()
	{
		assertTrue( Utils.isEmpty( null ) );
		assertTrue( Utils.isEmpty( "" ) );
		assertTrue( Utils.isEmpty( " " ) );
		assertFalse( Utils.isEmpty( "a" ) );
	}

	@Test(expected = NullPointerException.class )
	public void testGetSortedCaseInsensitiveArrayNullArg()
	{
		Utils.getSortedCaseInsensitiveArray( null );
	}

	@Test
	public void testGetSortedCaseInsensitiveArray()
	{
		Set<String> originalList = new HashSet<String>();
		originalList.add( "Z" );
		originalList.add( "n" );
		originalList.add( "K" );
		originalList.add( "t" );
		originalList.add( "k" );

		String[] result = Utils.getSortedCaseInsensitiveArray( originalList );

		assertEquals( result.length, 5 );

		//not testing "k" and "K" because I think that they can come in in any order

		assertEquals( result[2], "n" );
		assertEquals( result[3], "t" );
		assertEquals( result[4], "Z" );
	}

	private enum NumericalEnumImpl implements NumericalEnum
	{
		TEST;

		@Override
		public int getValue()
		{
			return 1;
		}		
	}
}
