package info.msxlaunchers.openmsx.game.repository;

import info.msxlaunchers.openmsx.game.repository.XMLRepositoryData;
import info.msxlaunchers.openmsx.game.repository.processor.XMLProcessor;
import info.msxlaunchers.openmsx.launcher.data.global.Settings;
import info.msxlaunchers.openmsx.launcher.persistence.settings.SettingsPersister;

import java.io.IOException;


import org.junit.Test;

import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

public class XMLRepositoryDataTest
{
	@Test( expected = NullPointerException.class )
	public void testForNullConditionsConstructorArg1() throws IOException
	{
		new XMLRepositoryData( null, mock( XMLProcessor.class ) );
	}

	@Test( expected = NullPointerException.class )
	public void testForNullConditionsConstructorArg2() throws IOException
	{
		SettingsPersister settingsPersister = mock( SettingsPersister.class );

		new XMLRepositoryData( settingsPersister, null );
	}

	@Test
	public void testGetRepositoryInfo() throws IOException
	{
		XMLProcessor xmlProcessor = mock( XMLProcessor.class );

		SettingsPersister settingsPersister = mock( SettingsPersister.class );
		when( settingsPersister.getSettings() ).thenReturn( new Settings( null, "machines-path", null, null, null ) );

		XMLRepositoryData xmlRepositoryData = new XMLRepositoryData( settingsPersister, xmlProcessor );

		xmlRepositoryData.getRepositoryInfo();
	}

	@Test( expected = IOException.class )
	public void testGetRepositoryInfoIOException() throws IOException
	{
		XMLProcessor xmlProcessor = mock( XMLProcessor.class );

		SettingsPersister settingsPersister = mock( SettingsPersister.class );
		when( settingsPersister.getSettings() ).thenThrow( new IOException() );

		XMLRepositoryData xmlRepositoryData = new XMLRepositoryData( settingsPersister, xmlProcessor );

		xmlRepositoryData.getRepositoryInfo();
	}

	@Test
	public void testGetGameInfo() throws IOException
	{
		XMLProcessor xmlProcessor = mock( XMLProcessor.class );

		SettingsPersister settingsPersister = mock( SettingsPersister.class );
		when( settingsPersister.getSettings() ).thenReturn( new Settings( null, "machines-path", null, null, null ) );

		XMLRepositoryData xmlRepositoryData = new XMLRepositoryData( settingsPersister, xmlProcessor );

		xmlRepositoryData.getGameInfo( "123" );
	}

	@Test( expected = IOException.class )
	public void testGetGameInfoIOException() throws IOException
	{
		XMLProcessor xmlProcessor = mock( XMLProcessor.class );

		SettingsPersister settingsPersister = mock( SettingsPersister.class );
		when( settingsPersister.getSettings() ).thenThrow( new IOException() );

		XMLRepositoryData xmlRepositoryData = new XMLRepositoryData( settingsPersister, xmlProcessor );

		xmlRepositoryData.getGameInfo( "123" );
	}

	@Test
	public void testGetOtherDumpCodes() throws IOException
	{
		XMLProcessor xmlProcessor = mock( XMLProcessor.class );

		SettingsPersister settingsPersister = mock( SettingsPersister.class );
		when( settingsPersister.getSettings() ).thenReturn( new Settings( null, null, null, null, null ) );

		XMLRepositoryData xmlRepositoryData = new XMLRepositoryData( settingsPersister, xmlProcessor );

		xmlRepositoryData.getOtherDumpCodes( "123" );
	}

	@Test( expected = IOException.class )
	public void testGetOtherDumpCodesIOException() throws IOException
	{
		XMLProcessor xmlProcessor = mock( XMLProcessor.class );

		SettingsPersister settingsPersister = mock( SettingsPersister.class );
		when( settingsPersister.getSettings() ).thenThrow( new IOException() );

		XMLRepositoryData xmlRepositoryData = new XMLRepositoryData( settingsPersister, xmlProcessor );

		xmlRepositoryData.getOtherDumpCodes( "123" );
	}

	@Test( expected = NullPointerException.class )
	public void testGetGameInfoNullArgument() throws IOException
	{
		XMLProcessor xmlProcessor = mock( XMLProcessor.class );

		SettingsPersister settingsPersister = mock( SettingsPersister.class );
		when( settingsPersister.getSettings() )
		.thenReturn( new Settings( "openMSXFullPath",
				"openMSXMachinesFullPath",
				"screenshotsFullPath",
				"defaultDatabase",
				null));

		XMLRepositoryData xmlRepositoryData = new XMLRepositoryData( settingsPersister, xmlProcessor );

		xmlRepositoryData.getGameInfo( null );
	}

	@Test( expected = NullPointerException.class )
	public void testGetOtherDumpCodesNullArgument() throws IOException
	{
		XMLProcessor xmlProcessor = mock( XMLProcessor.class );

		SettingsPersister settingsPersister = mock( SettingsPersister.class );
		when( settingsPersister.getSettings() )
		.thenReturn( new Settings( "openMSXFullPath",
				"openMSXMachinesFullPath",
				"screenshotsFullPath",
				"defaultDatabase",
				null));

		XMLRepositoryData xmlRepositoryData = new XMLRepositoryData( settingsPersister, xmlProcessor );

		xmlRepositoryData.getOtherDumpCodes( null );
	}
}
