/*
 * Copyright 2013 Sam Elsharif
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package info.msxlaunchers.openmsx.launcher.ui.view;

import info.msxlaunchers.openmsx.launcher.data.global.Settings;
import info.msxlaunchers.openmsx.launcher.data.global.constants.Language;
import info.msxlaunchers.openmsx.launcher.ui.presenter.GameLabel;
import info.msxlaunchers.openmsx.launcher.ui.presenter.LauncherPresenter;
import info.msxlaunchers.openmsx.launcher.ui.view.swing.AddEditWindow;
import info.msxlaunchers.openmsx.launcher.ui.view.swing.CreateEmptyDatabaseWindow;
import info.msxlaunchers.openmsx.launcher.ui.view.swing.FillDatabaseWindow;
import info.msxlaunchers.openmsx.launcher.ui.view.swing.HelpWindow;
import info.msxlaunchers.openmsx.launcher.ui.view.swing.MainWindow;
import info.msxlaunchers.openmsx.launcher.ui.view.swing.MoveGamesWindow;
import info.msxlaunchers.openmsx.launcher.ui.view.swing.SettingsWindow;
import info.msxlaunchers.openmsx.launcher.ui.view.swing.component.YesNoAllConfirmationWindow;

import java.util.Set;

import javax.swing.SwingUtilities;

/**
 * Swing-based implementation of <code>LauncherView</code>
 * 
 * @since v1.0
 * @author Sam Elsharif
 *
 */
class LauncherSwingView implements LauncherView
{
	private LauncherPresenter presenter;

	@Override
	public void setPresenter( LauncherPresenter presenter )
	{
		this.presenter = presenter;
	}

	MainWindow mainWindow = null;
	
	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#displayMain(info.msxlaunchers.openmsx.launcher.data.global.constants.Language, java.util.Set, java.util.Set, java.lang.String, boolean)
	 */
	@Override
	public void displayMain( Language language,
			Set<GameLabel> games,
			Set<String> databases,
			String defaultDatabase,
			boolean rightToLeft )
	{
		mainWindow = new MainWindow( presenter );

		SwingUtilities.invokeLater( new MainWindowStarter( language, games, databases, defaultDatabase, rightToLeft ) );
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#displaySettings(info.msxlaunchers.openmsx.launcher.data.global.Settings, java.util.Set, info.msxlaunchers.openmsx.launcher.data.global.constants.Language, java.lang.String, boolean)
	 */
	@Override
	public void displaySettings( Settings settings, Set<String> databases, Language language, String languageCode, boolean rightToLeft )
	{
		SettingsWindow settingsWindow = new SettingsWindow( presenter,
				settings,
				databases,
				language,
				languageCode,
				rightToLeft,
				mainWindow );

		settingsWindow.displaySettings();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#refreshLanguage(info.msxlaunchers.openmsx.launcher.data.global.constants.Language)
	 */
	@Override
	public void refreshLanguage( Language language )
	{
		mainWindow.refreshLanguage( language );
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#flipOrientationLeftToRight()
	 */
	@Override
	public void flipOrientationLeftToRight()
	{
		mainWindow.flipOrientationLeftToRight();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#flipOrientationRightToLeft()
	 */
	@Override
	public void flipOrientationRightToLeft()
	{
		mainWindow.flipOrientationRightToLeft();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#fillGameList(java.lang.String, java.util.Set, java.lang.String)
	 */
	@Override
	public void fillGameList( String currentDatabase, Set<GameLabel> games, String selectedGame )
	{
		mainWindow.fillGameList( currentDatabase, games, selectedGame );
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#displayAddEdit(info.msxlaunchers.openmsx.launcher.data.global.constants.Language, java.util.Set, java.util.Set, boolean)
	 */
	@Override
	public void displayAddEdit( Language language,
			Set<String> machines,
			Set<String> extensions,
			boolean rightToLeft )
	{
		AddEditWindow addEditWindow = new AddEditWindow(presenter,
				language,
				machines,
				extensions,
				rightToLeft,
				mainWindow,
				false);

		addEditWindow.display();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#displayAddEdit(info.msxlaunchers.openmsx.launcher.data.global.constants.Language, java.util.Set, java.util.Set, boolean, java.lang.String, java.lang.String, java.lang.String, java.lang.String, java.lang.String, java.lang.String, java.lang.String, java.lang.String, java.lang.String, java.lang.String, java.lang.String, java.lang.String)
	 */
	@Override
	public void displayAddEdit( Language language, Set<String> machines, Set<String> extensions, boolean rightToLeft,
			String name, String info, String machine, String romA, String romB, String extensionRom,
			String diskA, String diskB, String tape, String harddisk, String laserdisc, String script )
	{
		AddEditWindow addEditWindow = new AddEditWindow(presenter,
				language,
				machines,
				extensions,
				rightToLeft,
				mainWindow,
				true);

		addEditWindow.display( name, info, machine, romA, romB, extensionRom, diskA, diskB, tape, harddisk,
				laserdisc, script );
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#updateGameCount(int)
	 */
	@Override
	public void updateGameCount( int total )
	{
		mainWindow.updateGameCount( total );
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#displayFillDatabase(info.msxlaunchers.openmsx.launcher.data.global.constants.Language, java.util.Set, java.lang.String, java.util.Set, boolean)
	 */
	@Override
	public void displayFillDatabase( Language language,
			Set<String> databases,
			String currentDatabase,
			Set<String> machines,
			boolean rightToLeft )
	{
		FillDatabaseWindow fillDatabaseWindow = new FillDatabaseWindow( presenter,
																		language,
																		databases,
																		currentDatabase,
																		machines,
																		rightToLeft,
																		mainWindow );

		fillDatabaseWindow.display();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#displayAbout(info.msxlaunchers.openmsx.launcher.data.global.constants.Language, boolean)
	 */
	@Override
	public void displayAbout( Language language, boolean rightToLeft )
	{
		HelpWindow helpWindow = new HelpWindow( language, rightToLeft, mainWindow );

		helpWindow.display();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#showGameScreenshots(java.lang.String, java.lang.String)
	 */
	@Override
	public void showGameScreenshots( String screenshot1, String screenshot2 )
	{
		mainWindow.showGameScreenshot( screenshot1, screenshot2 );
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#enableButtons(boolean, boolean, boolean, boolean)
	 */
	@Override
	public void enableButtons( boolean launchFlag, boolean removeFlag, boolean editFlag, boolean infoFlag )
	{
		mainWindow.enableButtons( launchFlag, removeFlag, editFlag, infoFlag );
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#displayAndGetMoveGames(info.msxlaunchers.openmsx.launcher.data.global.constants.Language, java.util.Set, java.lang.String, java.util.Set, boolean)
	 */
	@Override
	public Set<String> displayAndGetMoveGames( Language language, Set<String> gameNames, String oldDatabase,
			Set<String> targetDatabases, boolean rightToLeft )
	{
		MoveGamesWindow moveGamesWindow = new MoveGamesWindow( presenter, language, rightToLeft, mainWindow,
				gameNames, oldDatabase, targetDatabases );

		return moveGamesWindow.displayAndGetMovedGames();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#displayAndGetActionDecider(java.lang.String, info.msxlaunchers.openmsx.launcher.data.global.constants.Language, boolean)
	 */
	@Override
	public int displayAndGetActionDecider( String gameName, Language language, boolean rightToLeft )
	{
		YesNoAllConfirmationWindow confirmationWindow = new YesNoAllConfirmationWindow( mainWindow, gameName, language,
				"CONFLICT_MESSAGE", rightToLeft );

		return confirmationWindow.displayAndGetResult();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#addDatabase(java.lang.String)
	 */
	@Override
	public void addDatabase( String database )
	{
		mainWindow.addDatabase( database );
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#displayCreateEmptyDatabase(info.msxlaunchers.openmsx.launcher.data.global.constants.Language, boolean)
	 */
	@Override
	public void displayCreateEmptyDatabase( Language language, boolean rightToLeft )
	{
		CreateEmptyDatabaseWindow createEmptyDatabaseWindow = new CreateEmptyDatabaseWindow( presenter, language, rightToLeft, mainWindow );

		createEmptyDatabaseWindow.displayAndGetNewDatabaseName();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.ui.view.LauncherView#showGameCompanyYearSizeData(java.lang.String, java.lang.String, java.lang.String)
	 */
	@Override
	public void showGameCompanyYearSizeData( String company, String year, long size )
	{
		mainWindow.showGameCompanyYearSizeData( company, year, size );
	}

	@Override
	public void resetGameCompanyYearSizeData()
	{
		mainWindow.resetGameCompanyYearSizeData();
	}

	private class MainWindowStarter implements Runnable
	{
		private final Language language;
		private final Set<GameLabel> games;
		private final Set<String> databases;
		private final String defaultDatabase;
		private final boolean rightToLeft;
		
		public MainWindowStarter( Language language,
				Set<GameLabel> games,
				Set<String> databases,
				String defaultDatabase,
				boolean rightToLeft )
		{
			this.language = language;
			this.games = games;
			this.databases = databases;
			this.defaultDatabase = defaultDatabase;
			this.rightToLeft = rightToLeft;
		}

		@Override
		public void run()
		{
			mainWindow.display( language, games, databases, defaultDatabase, rightToLeft );
		}		
	}
}
